require "rubygems"
require "bundler"

Bundler.setup
Bundler.require :default

class App < ::Sinatra::Base
    
  def self.configure(*envs, &block)
    yield self if envs.empty? || envs.include?(environment.to_sym) || (environment.to_s =~ /dev/ && envs.first.eql?(:development))
  end
  
  configure do
    
    set :root, File.join(File.expand_path(File.join(File.dirname(__FILE__))), '..')
    set :public_folder, File.join(root, 'public')
    set :sessions, true
    set :static, true
    set :app_config, YAML.load(ERB.new(File.read(File.join(root, 'config', 'app.yml'))).result)
    
    Dir.glob(File.join(root, 'models', '**/*.rb')).each { |f| require f }
    require File.join(root, 'app')
    
    DataMapper.finalize
    
    if app_config["instagram"]["client_id"].nil?
      raise ArgumentError, "Add your instagram config to ENV!"
    else
      Instagram.configure do |config|
        config.client_id = app_config["instagram"]["client_id"]
        config.client_secret = app_config["instagram"]["client_secret"]
      end
    end
    
    DataMapper::Logger.new STDOUT, :debug
    configure :production do
      DataMapper.setup :default, ENV['DATABASE_URL']
    end

    configure :development do
      DataMapper.setup :default, ENV['TPAMW_DATABASE_URL']
    end
     
  end

end

